@@ -98,13 +98,18 @@ def read_datapackage(url_or_path, resource_name=None):
             # Get missing values representations if defined
             missing_values = resource["schema"].get("missingValues", [''])
 
-            # Get decimal character and thousands separator if they are defined
+            # Get decimal character if they are defined
             decimal_char = resource["schema"].get("decimalChar", '.')
-            thousands_sep = resource["schema"].get("groupChar", None)
+
+            # Get encoding
+            encoding = resource.get("encoding", "utf-8")
 
             if "fields" in resource["schema"]:
                 for column in resource["schema"]["fields"]:
                     col_type = column.get("type", None)
+                    # Get thousands separator from field level, if defined.
+                    # Note that this will be applied to all fields.
+                    thousands_sep = column.get("groupChar", None)
                     if col_type == "number":
                         dtypes[column["name"]] = "float64"
                     elif col_type == "integer":
@@ -121,6 +126,7 @@ def read_datapackage(url_or_path, resource_name=None):
                 dtype=dtypes,
                 thousands=thousands_sep,
                 decimal=decimal_char,
+                encoding=encoding,
             )
         elif format == "geojson":
             import geopandas
